QueueJob

Struct QueueJob 

pub struct QueueJob {
Show 13 fields pub queue: String, pub id: String, pub body: String, pub attempts: u32, pub max_attempts: u32, pub status: QueueJobStatus, pub available_at_ms: i64, pub leased_at_ms: Option<i64>, pub lease_expires_at_ms: Option<i64>, pub completed_at_ms: Option<i64>, pub dead_at_ms: Option<i64>, pub created_at: String, pub last_error: String,
}
A queued unit of work.

Fields

queue: String

Queue name.

id: String

Stable job identifier.

body: String

Serialized job payload.

attempts: u32

Number of attempts already made.

max_attempts: u32

Maximum attempts before the job should be considered dead.

status: QueueJobStatus

Current job status.

available_at_ms: i64

Unix timestamp in milliseconds when this job becomes claimable.

leased_at_ms: Option<i64>

Unix timestamp in milliseconds when this job was leased.

lease_expires_at_ms: Option<i64>

Unix timestamp in milliseconds when this job lease expires.

completed_at_ms: Option<i64>

Unix timestamp in milliseconds when this job completed.

dead_at_ms: Option<i64>

Unix timestamp in milliseconds when this job moved to dead-letter state.

created_at: String

ISO 8601 creation timestamp. Empty if not set.

last_error: String

Error message from last nack. Empty if not set.

Implementations

Source

impl QueueJob

pub fn new( queue: impl Into<String>, id: impl Into<String>, body: impl Into<String>, max_attempts: u32, ) -> Self

Create a new ready job.

pub fn delay_by_ms(self, delay_ms: u64) -> Self

Make this job available after a delay.

pub const fn available_at_ms(self, available_at_ms: i64) -> Self

Set the exact Unix timestamp in milliseconds when this job is claimable.